pub fn _mm_extracti_si64(x: __m128i, const LEN: i32, const IDX: i32) -> __m128iAvailable on x86 and target feature
sse4a and (x86 or x86-64) only.Expand description
Extracts the specified bits from the lower 64 bits of the 128-bit integer vector operand at the
index idx and of the length len.
idx specifies the index of the LSB. len specifies the number of bits to extract. If length
and index are both zero, bits [63:0] of parameter x are extracted. It is a compile-time error
for len + idx to be greater than 64 or for len to be zero and idx to be non-zero.
The extracted bits are saved in the least-significant bit positions of the lower quadword of the destination; the remaining bits in the lower quadword of the destination register are cleared to 0. The upper quadword of the destination register is undefined.